@@ -40,16 +40,16 @@ FA <- c(rep(21, 8), rep(6, 6), rep(6, 8))
 ###################################################
 library(qMRI)
 mpm <- readMPMData(t1Files, pdFiles, mtFiles,
-                   maskFile, 
-                   TR = TR, TE = TE, FA = FA, 
+                   maskFile,
+                   TR = TR, TE = TE, FA = FA,
                    verbose = FALSE)
 
 
 ###################################################
 ### code chunk number 6: 5
 ###################################################
-modelMPM <- estimateESTATICS(mpm, 
-                             method = "NLR", 
+modelMPM <- estimateESTATICS(mpm,
+                             method = "NLR",
                              verbose = FALSE)
 
 
@@ -64,33 +64,42 @@ modelMPMQLsp1 <- smoothESTATICS(modelMPM,
                                 alpha = 0.004,
                                 patchsize = 1,
                                 verbose = FALSE)
-mpm$mask[,c(1:10,12:21),] <- FALSE
 
 
 ###################################################
-### code chunk number 8: 6
+### code chunk number 8: 7a
+###################################################
+# reduce mask to save time
+mask <- extract(mpm,"mask")
+mask[,c(1:10,12:21),] <- FALSE
+mpm <- qMRI:::setMPMmask(mpm, mask)
+
+
+###################################################
+### code chunk number 9: 6
 ###################################################
 sigma <- array(50, mpm$sdim)
-modelMPMQL <- estimateESTATICS(mpm, 
+modelMPMQL <- estimateESTATICS(mpm,
                                method = "QL",
-                               sigma = sigma, 
-                               L = 1, 
+                               sigma = sigma,
+                               L = 1,
                                verbose = FALSE)
 
 
 ###################################################
-### code chunk number 9: qMRI-Example.Rnw:225-227 (eval = FALSE)
+### code chunk number 10: qMRI-Example.Rnw:230-233 (eval = FALSE)
 ###################################################
 ## ddata <- extract(mpm,"ddata")
-## if(require(dti)) sigma <- awslsigmc(ddata[1,,,],16)$sigma
+## mask <- extract(mpm,"mask")
+## if(require(dti)) sigma <- awslsigmc(ddata[1,,,],16,mask)$sigma
 
 
 ###################################################
-### code chunk number 10: 7 (eval = FALSE)
+### code chunk number 11: 7 (eval = FALSE)
 ###################################################
-## # use setCores(ncores) to enable openMP parallelization 
+## # use setCores(ncores) to enable openMP parallelization
 ## setCores(2,reprt=FALSE)
-## modelMPMQLsp1 <- smoothESTATICS(modelMPM,
+## modelMPMQLsp1 <- smoothESTATICS(modelMPMQL,
 ##                                 mpmData = extract(mpm, "ddata"),
 ##                                 kstar = 16,
 ##                                 alpha = 0.004,
@@ -99,44 +108,45 @@ modelMPMQL <- estimateESTATICS(mpm,
 
 
 ###################################################
-### code chunk number 11: 8
+### code chunk number 12: 8
 ###################################################
 library(adimpro)
 rimage.options(zquantiles = c(.01, .99), ylab = "z")
-par(mfrow = c(2, 4), 
+par(mfrow = c(2, 4),
     mar = c(3, 3, 3, 1), mgp = c(2, 1, 0))
 pnames <- c("T1", "MT", "PD", "R2star")
 for (i in 1:4) {
-  rimage(modelMPMQL$modelCoeff[i, , 11, ])
+  modelCoeff <- extract(modelMPMQL,"modelCoeff")
+  rimage(modelCoeff[i, , 11, ])
   title(pnames[i])
 }
 for (i in 1:4) {
-  rimage(modelMPMQLsp1$modelCoeff[i, , 11, ])
+  modelCoeff <- extract(modelMPMQLsp1,"modelCoeff")
+  rimage(modelCoeff[i, , 11, ])
   title(paste("smoothed", pnames[i]))
 }
 
 
 ###################################################
-### code chunk number 12: 9a
-###################################################
-
-
-
-###################################################
-### code chunk number 13: 9
+### code chunk number 13: 9a
 ###################################################
 mpmsp1 <- mpm
-mpmsp1$ddata <- modelMPMQLsp1$smoothedData
-sigma <- array(50, mpm$sdim)
-modelMPMQL2 <- estimateESTATICS(mpmsp1, 
-                                method = "QL",
-                                sigma = sigma, 
-                                L = 1, 
+ddata <- extract(modelMPMQLsp1,"smoothedData")
+dim(ddata) <- c(dim(ddata)[1],prod(dim(ddata)[-1]))
+mpmsp1$ddata <- ddata[,mpm$mask]
+
+
+###################################################
+### code chunk number 14: 9
+###################################################
+modelMPM2 <- estimateESTATICS(mpmsp1,
+                                method = "NLR",
+                                L = 1,
                                 verbose = FALSE)
 
 
 ###################################################
-### code chunk number 14: 10
+### code chunk number 15: 10
 ###################################################
 qMRIMaps <- calculateQI(modelMPM,
                         b1File = B1File,
@@ -147,13 +157,13 @@ qMRIQLMaps <- calculateQI(modelMPMQL,
 qMRIQLSmoothedp1Maps <- calculateQI(modelMPMQLsp1,
                                     b1File = B1File,
                                     TR2 = 3.4)
-qMRIQL2Maps <- calculateQI(modelMPMQL2,
+qMRIMaps2 <- calculateQI(modelMPM2,
                            b1File = B1File,
                            TR2 = 3.4)
 
 
 ###################################################
-### code chunk number 15: 11
+### code chunk number 16: 11
 ###################################################
 library(oro.nifti)
 zlim <- matrix(c(0, 0, 0, 3000,
@@ -167,37 +177,37 @@ rimage.options(ylab = "z")
 par(mfrow = c(4, 4),
     mar = c(3, 3, 3, 1), mgp = c(2, 1, 0))
 nmaps <- c("R1", "R2star", "MT", "PD")
-rimage(R1[, 11, ], zlim = zlim[1, ], 
+rimage(R1[, 11, ], zlim = zlim[1, ],
        main = paste("true", nmaps[1]))
-rimage(R2star[, 11, ], zlim = zlim[2, ], 
+rimage(R2star[, 11, ], zlim = zlim[2, ],
        main = paste("true", nmaps[2]))
-rimage(MT[, 11, ], zlim = zlim[3, ], 
+rimage(MT[, 11, ], zlim = zlim[3, ],
        main = paste("true", nmaps[3]),
        col = colMT)
-rimage(PD[, 11, ], zlim = zlim[4, ], 
+rimage(PD[, 11, ], zlim = zlim[4, ],
        main = paste("true", nmaps[4]))
 qmap1 <- extract(qMRIQLMaps, nmaps)
-for (i in 1:4) rimage(qmap1[[i]][, 11, ], zlim = zlim[i, ], 
+for (i in 1:4) rimage(qmap1[[i]][, 11, ], zlim = zlim[i, ],
                       main = paste("Estimated", nmaps[i]),
                       col = if(i==3) colMT else grey(0:225/255))
 qmap2 <- extract(qMRIQLSmoothedp1Maps, nmaps)
-for (i in 1:4) rimage(qmap2[[i]][, 11, ], zlim = zlim[i, ], 
+for (i in 1:4) rimage(qmap2[[i]][, 11, ], zlim = zlim[i, ],
                       main = paste("Smoothed", nmaps[i]),
                       col = if(i==3) colMT else grey(0:225/255))
-qmap3 <- extract(qMRIQL2Maps, nmaps)
+qmap3 <- extract(qMRIMaps2, nmaps)
 for (i in 1:4) rimage(qmap3[[i]][, 11, ], zlim = zlim[i, ],
                       main = paste("Smoothed data", nmaps[i]),
                       col = if(i==3) colMT else grey(0:225/255))
 
 
 ###################################################
-### code chunk number 16: 12
+### code chunk number 17: 12
 ###################################################
 qmap0 <- extract(qMRIMaps,nmaps)
 mask <- extract(mpm,"mask")
-cat("\n", 
+cat("\n",
     "Bias of NLR estimates\n",
-      "R1", mean((qmap0$R1-R1)[mask]), 
+      "R1", mean((qmap0$R1-R1)[mask]),
       "R2star", mean((qmap0$R2star-R2star)[mask]),
       "MT", mean((qmap0$MT-MT)[mask]),
       "PD", mean((qmap0$PD-PD)[mask]), "\n",
@@ -209,9 +219,9 @@ cat("\n",
 
 
 ###################################################
-### code chunk number 17: 13
+### code chunk number 18: 13
 ###################################################
-cat("\n", 
+cat("\n",
     "Root mean squared error of NLR estimate\n",
       "R1", sqrt(mean((qmap0$R1-R1)[mask]^2)),
       "R2star", sqrt(mean((qmap0$R2star-R2star)[mask]^2)),
@@ -227,7 +237,7 @@ cat("\n",
       "R2star", sqrt(mean((qmap2$R2star-R2star)[mask]^2)),
       "MT", sqrt(mean((qmap2$MT-MT)[mask]^2)),
       "PD", sqrt(mean((qmap2$PD-PD)[mask]^2)),"\n",
-    "Root mean squared error of QL estimate from smoothed data \n",
+    "Root mean squared error of estimate from smoothed data \n",
       "R1", sqrt(mean((qmap3$R1-R1)[mask]^2)),
       "R2star", sqrt(mean((qmap3$R2star-R2star)[mask]^2)),
       "MT", sqrt(mean((qmap3$MT-MT)[mask]^2)),
@@ -235,10 +245,10 @@ cat("\n",
 
 
 ###################################################
-### code chunk number 18: 14
+### code chunk number 19: 14
 ###################################################
-cat("Mean R1", mean(R1[mask]), "Mean R2star", 
-    mean(R2star[mask]), "Mean MT", mean(MT[mask]), 
+cat("Mean R1", mean(R1[mask]), "Mean R2star",
+    mean(R2star[mask]), "Mean MT", mean(MT[mask]),
     "Mean PD", mean(PD[mask]),"\n")
 
 
